@@ -45,6 +45,7 @@
 #ifdef ESP_IDF_COMP_ESP_NETIF_ENABLED
 #include "esp_wifi_netif.h"
 #endif
+#include "esp_now.h"
 #endif
 
 #ifdef ESP_IDF_COMP_ESP_ETH_ENABLED
@@ -117,6 +118,12 @@
 #include "nvs_flash.h"
 #endif
 
+#ifdef ESP_IDF_COMP_ESP_WIFI_PROVISIONING_ENABLED
+#include "wifi_provisioning/manager.h"
+#include "wifi_provisioning/scheme_ble.h"
+#include "wifi_provisioning/scheme_softap.h"
+#endif
+
 #ifdef ESP_IDF_COMP_SOC_ENABLED
 // TODO: Include all XXX_periph.h headers here
 #include "soc/gpio_periph.h"
